@@ -15,6 +15,7 @@ from dateparser.utils.strptime import strptime
 NSP_COMPATIBLE = re.compile(r'\D+')
 MERIDIAN = re.compile(r'am|pm')
 MICROSECOND = re.compile(r'\d{1,6}')
+EIGHT_DIGIT = re.compile(r'^\d{8}$')
 
 
 def no_space_parser_eligibile(datestring):
@@ -93,6 +94,7 @@ class _time_parser(object):
         else:
             raise ValueError('%s does not seem to be a valid time string' % _timestring)
 
+
 time_parser = _time_parser()
 
 
@@ -106,6 +108,8 @@ class _no_spaces_parser(object):
 
     _preferred_formats = ['%Y%m%d%H%M', '%Y%m%d%H%M%S', '%Y%m%d%H%M%S.%f']
 
+    _preferred_formats_ordered_8_digit = ['%m%d%Y', '%d%m%Y', '%Y%m%d', '%Y%d%m', '%m%Y%d', '%d%Y%m']
+
     _timeformats = ['%H%M%S.%f', '%H%M%S', '%H%M', '%H']
 
     period = {
@@ -142,6 +146,17 @@ class _no_spaces_parser(object):
         else:
             return 'year'
 
+    @classmethod
+    def _find_best_matching_date(cls, datestring):
+        for fmt in cls._preferred_formats_ordered_8_digit:
+            try:
+                dt = strptime(datestring, fmt), cls._get_period(fmt)
+                if len(str(dt[0].year)) == 4:
+                    return dt
+            except:
+                pass
+        return None
+
     @classmethod
     def parse(cls, datestring, settings):
         if not no_space_parser_eligibile(datestring):
@@ -155,6 +170,10 @@ class _no_spaces_parser(object):
             order = resolve_date_order(settings.DATE_ORDER)
         else:
             order = cls._default_order
+            if EIGHT_DIGIT.match(datestring):
+                dt = cls._find_best_matching_date(datestring)
+                if dt is not None:
+                    return dt
         nsp = cls()
         ambiguous_date = None
         for token, _ in tokens.tokenize():
@@ -295,7 +314,7 @@ class _parser(object):
         try:
             return datetime(**params)
         except ValueError as e:
-            error_text = getattr(e, 'message', None) or e.__str__()
+            error_text = e.__str__()
             error_msgs = ['day is out of range', 'day must be in']
             if (
                 (error_msgs[0] in error_text or error_msgs[1] in error_text) and
@@ -326,17 +345,21 @@ class _parser(object):
     def _get_date_obj(self, token, directive):
         return strptime(token, directive)
 
+    def _missing_error(self, missing):
+        return ValueError(
+            'Fields missing from the date string: {}'.format(', '.join(missing))
+        )
+
     def _results(self):
-        if self.settings.STRICT_PARSING:
-            errors = []
-            if not self.day:
-                errors.append('Day')
-            if not self.month:
-                errors.append('Month')
-            if not self.year:
-                errors.append('Year')
+        missing = [field for field in ('day', 'month', 'year')
+                   if not getattr(self, field)]
+
+        if self.settings.STRICT_PARSING and missing:
+            raise self._missing_error(missing)
+        elif self.settings.REQUIRE_PARTS and missing:
+            errors = [part for part in self.settings.REQUIRE_PARTS if part in missing]
             if errors:
-                raise ValueError('%s not found in the date string' % ''.join(errors))
+                raise self._missing_error(errors)
 
         self._set_relative_base()
 
